@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
-
 import collections
+
 from ucloud.core.utils import compact
 
 
@@ -14,7 +13,7 @@ MAX_COMMON_RET_CODE = 2000
 
 
 class RetCodeException(UCloudException):
-    def __init__(self, action, code, message):
+    def __init__(self, action: str, code: int, message: str):
         self.action = action
         self.code = code
         self.message = message
@@ -26,6 +25,13 @@ class RetCodeException(UCloudException):
     def __str__(self):
         return "{self.action} - {self.code}: {self.message}".format(self=self)
 
+    def json(self):
+        return {
+            "RetCode": self.code,
+            "Message": self.message or "",
+            "Action": self.action or "",
+        }
+
 
 class RetryTimeoutException(UCloudException):
     pass
