@@ -1,6 +1,6 @@
-# -*- coding: utf-8 -*-
-
 import json
+import typing
+
 from ucloud.core.transport import Transport, Request, Response
 
 
@@ -10,17 +10,19 @@ class MockedTransport(Transport):
         self.transport_handlers = []
         self.client_handler = []
 
-    def send(self, req, **options):
+    def send(self, req: Request, **options: dict) -> Response:
         resp = Response(req.url, req.method)
         for handler in self.transport_handlers:
             resp = handler(req)
+
         for handler in self.client_handler:
             payload = handler(req.payload())
-            resp.content = json.dumps(payload).encode("utf-8")
+            resp.content = json.dumps(payload).encode('utf-8')
+
         return resp
 
-    def mock(self, handler):
+    def mock(self, handler: typing.Callable[[Request], Response]):
         self.transport_handlers.append(handler)
 
-    def mock_data(self, handler):
+    def mock_data(self, handler: typing.Callable[[dict], dict]):
         self.client_handler.append(handler)
